@@ -48,7 +48,8 @@
 #' @note
 #' There are `print_html()` and `print_md()` methods available for printing
 #' frequency or crosstables in HTML and markdown format, e.g.
-#' `print_html(data_tabulate(x))`.
+#' `print_html(data_tabulate(x))`. The `print()` method for text outputs passes
+#' arguments in `...` to [`insight::export_table()`].
 #'
 #' @return A data frame, or a list of data frames, with one frequency table
 #' as data frame per variable.
@@ -397,6 +398,11 @@ insight::print_html
 insight::print_md
 
 
+#' @importFrom insight display
+#' @export
+insight::display
+
+
 #' @rdname data_tabulate
 #' @param add_total For crosstables (i.e. when `by` is not `NULL`), a row and
 #' column with the total N values are added to the data frame. `add_total` has
@@ -522,7 +528,8 @@ print.datawizard_table <- function(x, big_mark = NULL, ...) {
   cat(insight::export_table(
     format(x, big_mark = big_mark, ...),
     cross = "+",
-    missing = "<NA>"
+    missing = "<NA>",
+    ...
   ))
   invisible(x)
 }
@@ -603,8 +610,12 @@ print.datawizard_tables <- function(x, big_mark = NULL, ...) {
     x <- lapply(x, function(i) {
       i_attr <- attributes(i)
       i <- format(i, format = "text", big_mark = big_mark, ...)
-      i$Variable[i_attr$duplicate_varnames] <- ""
-      if (!is.null(i$Group)) i$Group[i_attr$duplicate_varnames] <- ""
+      if (!is.null(i$Variable)) {
+        i$Variable[i_attr$duplicate_varnames] <- ""
+      }
+      if (!is.null(i$Group)) {
+        i$Group[i_attr$duplicate_varnames] <- ""
+      }
       i[nrow(i) + 1, ] <- ""
       i
     })
@@ -621,7 +632,8 @@ print.datawizard_tables <- function(x, big_mark = NULL, ...) {
       out,
       missing = "<NA>",
       cross = "+",
-      empty_line = "-"
+      empty_line = "-",
+      ...
     ))
   }
 }
@@ -638,7 +650,9 @@ print_html.datawizard_tables <- function(x, big_mark = NULL, ...) {
     x <- lapply(x, function(i) {
       i_attr <- attributes(i)
       i <- format(i, format = "html", big_mark = big_mark, ...)
-      i$Variable[i_attr$duplicate_varnames] <- ""
+      if (!is.null(i$Variable)) {
+        i$Variable[i_attr$duplicate_varnames] <- ""
+      }
       i
     })
 
@@ -667,8 +681,12 @@ print_md.datawizard_tables <- function(x, big_mark = NULL, ...) {
     x <- lapply(x, function(i) {
       i_attr <- attributes(i)
       i <- format(i, format = "markdown", big_mark = big_mark, ...)
-      i$Variable[i_attr$duplicate_varnames] <- ""
-      if (!is.null(i$Group)) i$Group[i_attr$duplicate_varnames] <- ""
+      if (!is.null(i$Variable)) {
+        i$Variable[i_attr$duplicate_varnames] <- ""
+      }
+      if (!is.null(i$Group)) {
+        i$Group[i_attr$duplicate_varnames] <- ""
+      }
       i[nrow(i) + 1, ] <- ""
       i
     })
@@ -687,8 +705,6 @@ print_md.datawizard_tables <- function(x, big_mark = NULL, ...) {
 }
 
 
-
-
 # tools --------------------
 
 .table_header <- function(x, format = "text") {
