@@ -1,10 +1,11 @@
 test_that("adjust multilevel", {
-  skip_if_not_or_load_if_installed("lme4")
+  skip_if_not_installed("lme4")
   adj <- adjust(iris[c("Sepal.Length", "Species")], multilevel = TRUE, bayesian = FALSE)
+  # High tolerance to avoid issues on some R CMD check specification, see #592
   expect_equal(
     head(adj$Sepal.Length),
     c(0.08698, -0.11302, -0.31302, -0.41302, -0.01302, 0.38698),
-    tolerance = 1e-3
+    tolerance = 1e-1
   )
 })
 
@@ -28,3 +29,13 @@ test_that("adjust regex", {
     adjust(mtcars, select = "mpg")
   )
 })
+
+# select helpers ------------------------------
+test_that("adjust, invalid column names", {
+  data(iris)
+  colnames(iris)[1] <- "I am"
+  expect_error(
+    adjust(iris[c("I am", "Species")], multilevel = FALSE, bayesian = FALSE),
+    regex = "Bad column names"
+  )
+})
