@@ -21,7 +21,6 @@ test_that("data_read - csv", {
 })
 
 
-
 # csv -------------------------
 
 test_that("data_read, skip_empty", {
@@ -34,7 +33,6 @@ test_that("data_read, skip_empty", {
 })
 
 
-
 # tsv -------------------------
 
 test_that("data_read - tsv", {
@@ -57,7 +55,6 @@ test_that("data_read - tsv", {
 })
 
 
-
 # excel -------------------------
 
 test_that("data_read - excel", {
@@ -105,7 +102,6 @@ test_that("data_read - Stata file", {
 })
 
 
-
 # SAS file -----------------------------------
 
 
@@ -131,8 +127,6 @@ test_that("data_read - SAS file", {
 })
 
 
-
-
 # RDS file, matrix, coercible -----------------------------------
 
 test_that("data_read - RDS file, matrix, coercible", {
@@ -141,12 +135,12 @@ test_that("data_read - RDS file, matrix, coercible", {
     httr::stop_for_status(request)
     writeBin(httr::content(request, type = "raw"), temp_file)
 
-    expect_message(expect_message(expect_message({
+    expect_message({
       d <- data_read(
         temp_file,
         verbose = TRUE
       )
-    })), regex = "0 out of 5")
+    })
 
     expect_s3_class(d, "data.frame")
     expect_identical(dim(d), c(2L, 5L))
@@ -154,6 +148,55 @@ test_that("data_read - RDS file, matrix, coercible", {
 })
 
 
+# RDS file, preserve class /types -----------------------------------
+
+test_that("data_read - RDS file, preserve class", {
+  withr::with_tempfile("temp_file", fileext = ".rds", code = {
+    request <- httr::GET("https://raw.github.com/easystats/circus/main/data/hiv.rds")
+    httr::stop_for_status(request)
+    writeBin(httr::content(request, type = "raw"), temp_file)
+
+    d <- data_read(temp_file, verbose = FALSE)
+    expect_s3_class(d, "data.frame")
+    expect_identical(
+      sapply(d, class),
+      c(
+        village = "integer", outcome = "integer", distance = "numeric",
+        amount = "numeric", incentive = "integer", age = "integer",
+        hiv2004 = "integer", agecat = "factor"
+      )
+    )
+  })
+})
+
+
+# RData -----------------------------------
+
+test_that("data_read - no warning for RData", {
+  withr::with_tempfile("temp_file", fileext = ".RData", code = {
+    data(mtcars)
+    save(mtcars, file = temp_file)
+    expect_silent(data_read(temp_file, verbose = FALSE))
+  })
+})
+
+
+test_that("data_read - message for multiple objects in RData", {
+  withr::with_tempfile("temp_file", fileext = ".RData", code = {
+    data(mtcars)
+    data(iris)
+    save(mtcars, iris, file = temp_file)
+    expect_message(
+      expect_message(
+        data_read(temp_file, verbose = TRUE),
+        regex = "File contained more than one object"
+      ),
+      "Reading data"
+    )
+  })
+})
+
+
 # SPSS file -----------------------------------
 
 test_that("data_read - SPSS file", {
@@ -189,8 +232,6 @@ test_that("data_read - SPSS file", {
 })
 
 
-
-
 # SPSS file 2 ---------------------------------
 
 test_that("data_read - SPSS file 2", {
@@ -239,7 +280,6 @@ test_that("data_read - SPSS file 2", {
 })
 
 
-
 # zipped SPSS file -----------------------------------
 
 test_that("data_read - zipped SPSS file", {
@@ -266,7 +306,6 @@ test_that("data_read - zipped SPSS file", {
 })
 
 
-
 # SPSS file, many value labels  -----------------------------------
 
 test_that("data_read, convert many labels correctly", {
@@ -387,8 +426,6 @@ test_that("data_read, convert many labels correctly", {
 })
 
 
-
-
 # invalid file type -------------------------
 
 test_that("data_read, no file extension", {
@@ -412,20 +449,70 @@ test_that("data_read, file not exists", {
 test_that("data_read - RDS file, no data frame", {
   skip_if_not_installed("withr")
 
+  withr::with_tempfile("temp_file", fileext = ".rda", code = {
+    request <- httr::GET("https://raw.github.com/easystats/circus/main/data/list_for_testing.rda")
+    httr::stop_for_status(request)
+    writeBin(httr::content(request, type = "raw"), temp_file)
+
+    expect_message(
+      expect_warning(
+        d <- data_read(temp_file, verbose = TRUE), # nolint
+        regex = "no data frame"
+      ),
+      "Reading data"
+    )
+    expect_type(d, "list")
+  })
+})
+
+test_that("data_read - RDA file, model object", {
+  skip_if_not_installed("withr")
+  skip_if_not_installed("brms")
+
   withr::with_tempfile("temp_file", fileext = ".rds", code = {
     request <- httr::GET("https://raw.github.com/easystats/circus/main/data/model_object.rds")
     httr::stop_for_status(request)
     writeBin(httr::content(request, type = "raw"), temp_file)
 
-    expect_warning(
-      {
-        d <- data_read(
-          temp_file,
-          verbose = TRUE
-        )
-      },
-      regex = "no data frame"
+    expect_message(
+      expect_message(
+        d <- data_read(temp_file, verbose = TRUE), # nolint
+        regex = "Imported file is a regression"
+      ),
+      "Reading data"
     )
     expect_s3_class(d, "lm")
   })
+
+  withr::with_tempfile("temp_file", fileext = ".rda", code = {
+    request <- httr::GET("https://raw.github.com/easystats/circus/main/data/brms_1.rda")
+    httr::stop_for_status(request)
+    writeBin(httr::content(request, type = "raw"), temp_file)
+
+    expect_message(
+      expect_message(
+        d <- data_read(temp_file, verbose = TRUE), # nolint
+        regex = "Imported file is a regression"
+      ),
+      "Reading data"
+    )
+    expect_s3_class(d, "brmsfit")
+  })
+})
+
+
+test_that("data_read - RDS file, from URL", {
+  # works with URL
+  request <- httr::GET("https://raw.github.com/easystats/circus/main/data/model_object.rds")
+  httr::stop_for_status(request)
+  expect_message(
+    expect_message(
+      d <- data_read( # nolint
+        "https://raw.github.com/easystats/circus/main/data/model_object.rds",
+        verbose = TRUE
+      ),
+      regex = "Imported file is a regression"
+    ),
+    "Reading data"
+  )
 })
